@@ -21,9 +21,17 @@ from typing import TYPE_CHECKING, Any, Iterable, Optional
 
 from typing_extensions import Annotated
 
+from airflow.exceptions import AirflowRescheduleException, TaskDeferred
 from airflow.models import Operator
 from airflow.models.baseoperator import BaseOperator
-from airflow.models.taskinstance import TaskInstance
+from airflow.models.taskinstance import (
+    TaskInstance,
+    TaskReturnCode,
+    _defer_task,
+    _handle_reschedule,
+    _run_raw_task,
+    _set_ti_attrs,
+)
 from airflow.serialization.pydantic.dag import DagModelPydantic
 from airflow.serialization.pydantic.dag_run import DagRunPydantic
 from airflow.utils.log.logging_mixin import LoggingMixin
@@ -49,20 +57,21 @@ if TYPE_CHECKING:
 
 def serialize_operator(x: Operator | None) -> dict | None:
     if x:
-        from airflow.serialization.serialized_objects import SerializedBaseOperator
+        from airflow.serialization.serialized_objects import BaseSerialization
 
-        return SerializedBaseOperator.serialize_operator(x)
+        return BaseSerialization.serialize(x, use_pydantic_models=True)
     return None
 
 
 def validated_operator(x: dict[str, Any] | Operator, _info: ValidationInfo) -> Any:
     from airflow.models.baseoperator import BaseOperator
     from airflow.models.mappedoperator import MappedOperator
-    from airflow.serialization.serialized_objects import SerializedBaseOperator
 
     if isinstance(x, BaseOperator) or isinstance(x, MappedOperator) or x is None:
         return x
-    return SerializedBaseOperator.deserialize_operator(x)
+    from airflow.serialization.serialized_objects import BaseSerialization
+
+    return BaseSerialization.deserialize(x, use_pydantic_models=True)
 
 
 PydanticOperator = Annotated[
@@ -85,7 +94,6 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
     duration: Optional[float]
     state: Optional[str]
     try_number: int
-    _try_number: int
     max_tries: int
     hostname: str
     unixname: str
@@ -99,6 +107,7 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
     queued_dttm: Optional[datetime]
     queued_by_job_id: Optional[int]
     pid: Optional[int]
+    executor: Optional[str]
     executor_config: Any
     updated_at: Optional[datetime]
     rendered_map_index: Optional[str]
@@ -126,6 +135,31 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
     def set_state(self, state, session: Session | None = None) -> bool:
         return TaskInstance._set_state(ti=self, state=state, session=session)
 
+    def _run_raw_task(
+        self,
+        mark_success: bool = False,
+        test_mode: bool = False,
+        job_id: str | None = None,
+        pool: str | None = None,
+        raise_on_defer: bool = False,
+        session: Session | None = None,
+    ) -> TaskReturnCode | None:
+        return _run_raw_task(
+            ti=self,
+            mark_success=mark_success,
+            test_mode=test_mode,
+            job_id=job_id,
+            pool=pool,
+            raise_on_defer=raise_on_defer,
+            session=session,
+        )
+
+    def _run_execute_callback(self, context, task):
+        TaskInstance._run_execute_callback(self=self, context=context, task=task)  # type: ignore[arg-type]
+
+    def render_templates(self, context: Context | None = None, jinja_env=None):
+        return TaskInstance.render_templates(self=self, context=context, jinja_env=jinja_env)  # type: ignore[arg-type]
+
     def init_run_context(self, raw: bool = False) -> None:
         """Set the log context."""
         self.raw = raw
@@ -137,6 +171,7 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
         dag_id: str | None = None,
         key: str = XCOM_RETURN_KEY,
         include_prior_dates: bool = False,
+        session: Session | None = None,
         *,
         map_indexes: int | Iterable[int] | None = None,
         default: Any = None,
@@ -144,17 +179,26 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
         """
         Pull an XCom value for this task instance.
 
-        TODO: make it works for AIP-44
         :param task_ids: task id or list of task ids, if None, the task_id of the current task is used
         :param dag_id: dag id, if None, the dag_id of the current task is used
         :param key: the key to identify the XCom value
         :param include_prior_dates: whether to include prior execution dates
+        :param session: the sqlalchemy session
         :param map_indexes: map index or list of map indexes, if None, the map_index of the current task
             is used
         :param default: the default value to return if the XCom value does not exist
         :return: Xcom value
         """
-        return None
+        return TaskInstance.xcom_pull(
+            self=self,  # type: ignore[arg-type]
+            task_ids=task_ids,
+            dag_id=dag_id,
+            key=key,
+            include_prior_dates=include_prior_dates,
+            map_indexes=map_indexes,
+            default=default,
+            session=session,
+        )
 
     def xcom_push(
         self,
@@ -166,12 +210,17 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
         """
         Push an XCom value for this task instance.
 
-        TODO: make it works for AIP-44
         :param key: the key to identify the XCom value
         :param value: the value of the XCom
         :param execution_date: the execution date to push the XCom for
         """
-        pass
+        return TaskInstance.xcom_push(
+            self=self,  # type: ignore[arg-type]
+            key=key,
+            value=value,
+            execution_date=execution_date,
+            session=session,
+        )
 
     def get_dagrun(self, session: Session | None = None) -> DagRunPydantic:
         """
@@ -239,8 +288,12 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
         """
         from airflow.models.taskinstance import _get_template_context
 
+        if TYPE_CHECKING:
+            assert self.task
+            assert self.task.dag
         return _get_template_context(
             task_instance=self,
+            dag=self.task.dag,
             session=session,
             ignore_param_exceptions=ignore_param_exceptions,
         )
@@ -253,7 +306,7 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
 
     def handle_failure(
         self,
-        error: None | str | Exception | KeyboardInterrupt,
+        error: None | str | BaseException,
         test_mode: bool | None = None,
         context: Context | None = None,
         force_fail: bool = False,
@@ -270,6 +323,13 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
         """
         from airflow.models.taskinstance import _handle_failure
 
+        if TYPE_CHECKING:
+            assert self.task
+            assert self.task.dag
+        try:
+            fail_stop = self.task.dag.fail_stop
+        except Exception:
+            fail_stop = False
         _handle_failure(
             task_instance=self,
             error=error,
@@ -277,6 +337,7 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
             test_mode=test_mode,
             context=context,
             force_fail=force_fail,
+            fail_stop=fail_stop,
         )
 
     def refresh_from_task(self, task: Operator, pool_override: str | None = None) -> None:
@@ -320,6 +381,21 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
 
         return _get_previous_execution_date(task_instance=self, state=state, session=session)
 
+    def get_previous_start_date(
+        self,
+        state: DagRunState | None = None,
+        session: Session | None = None,
+    ) -> pendulum.DateTime | None:
+        """
+        Return the execution date from property previous_ti_success.
+
+        :param state: If passed, it only take into account instances of a specific state.
+        :param session: SQLAlchemy ORM Session
+        """
+        from airflow.models.taskinstance import _get_previous_start_date
+
+        return _get_previous_start_date(task_instance=self, state=state, session=session)
+
     def email_alert(self, exception, task: BaseOperator) -> None:
         """
         Send alert email with exception information.
@@ -397,9 +473,9 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
 
         :meta: private
         """
-        return TaskInstance._schedule_downstream_tasks(
-            ti=self, session=session, max_tis_per_query=max_tis_per_query
-        )
+        # we should not schedule downstream tasks with Pydantic model because it will not be able to
+        # get the DAG object (we do not serialize it currently).
+        return
 
     def command_as_list(
         self,
@@ -437,6 +513,44 @@ class TaskInstancePydantic(BaseModelPydantic, LoggingMixin):
             cfg_path=cfg_path,
         )
 
+    def _register_dataset_changes(self, *, events, session: Session | None = None) -> None:
+        TaskInstance._register_dataset_changes(self=self, events=events, session=session)  # type: ignore[arg-type]
+
+    def defer_task(self, exception: TaskDeferred, session: Session | None = None):
+        """Defer task."""
+        updated_ti = _defer_task(ti=self, exception=exception, session=session)
+        _set_ti_attrs(self, updated_ti)
+
+    def _handle_reschedule(
+        self,
+        actual_start_date: datetime,
+        reschedule_exception: AirflowRescheduleException,
+        test_mode: bool = False,
+        session: Session | None = None,
+    ):
+        updated_ti = _handle_reschedule(
+            ti=self,
+            actual_start_date=actual_start_date,
+            reschedule_exception=reschedule_exception,
+            test_mode=test_mode,
+            session=session,
+        )
+        _set_ti_attrs(self, updated_ti)  # _handle_reschedule is a remote call that mutates the TI
+
+    def get_relevant_upstream_map_indexes(
+        self,
+        upstream: Operator,
+        ti_count: int | None,
+        *,
+        session: Session | None = None,
+    ) -> int | range | None:
+        return TaskInstance.get_relevant_upstream_map_indexes(
+            self=self,  # type: ignore[arg-type]
+            upstream=upstream,
+            ti_count=ti_count,
+            session=session,
+        )
+
 
 if is_pydantic_2_installed():
     TaskInstancePydantic.model_rebuild()
